# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/devtools/build/v1/publish_build_event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buildgrid.common.protos.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from buildgrid.common.protos.google.api import client_pb2 as google_dot_api_dot_client__pb2
from buildgrid.common.protos.google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from buildgrid.common.protos.google.devtools.build.v1 import build_events_pb2 as google_dot_devtools_dot_build_dot_v1_dot_build__events__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2google/devtools/build/v1/publish_build_event.proto\x12\x18google.devtools.build.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a+google/devtools/build/v1/build_events.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xe3\x02\n\x1cPublishLifecycleEventRequest\x12Z\n\rservice_level\x18\x01 \x01(\x0e\x32\x43.google.devtools.build.v1.PublishLifecycleEventRequest.ServiceLevel\x12\x46\n\x0b\x62uild_event\x18\x02 \x01(\x0b\x32+.google.devtools.build.v1.OrderedBuildEventB\x04\xe2\x41\x01\x02\x12\x31\n\x0estream_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1d\n\x15notification_keywords\x18\x04 \x03(\t\x12\x18\n\nproject_id\x18\x06 \x01(\tB\x04\xe2\x41\x01\x02\"3\n\x0cServiceLevel\x12\x12\n\x0eNONINTERACTIVE\x10\x00\x12\x0f\n\x0bINTERACTIVE\x10\x01\"u\n#PublishBuildToolEventStreamResponse\x12\x35\n\tstream_id\x18\x01 \x01(\x0b\x32\".google.devtools.build.v1.StreamId\x12\x17\n\x0fsequence_number\x18\x02 \x01(\x03\"\x98\x01\n\x11OrderedBuildEvent\x12\x35\n\tstream_id\x18\x01 \x01(\x0b\x32\".google.devtools.build.v1.StreamId\x12\x17\n\x0fsequence_number\x18\x02 \x01(\x03\x12\x33\n\x05\x65vent\x18\x03 \x01(\x0b\x32$.google.devtools.build.v1.BuildEvent\"\xad\x01\n\"PublishBuildToolEventStreamRequest\x12N\n\x13ordered_build_event\x18\x04 \x01(\x0b\x32+.google.devtools.build.v1.OrderedBuildEventB\x04\xe2\x41\x01\x02\x12\x1d\n\x15notification_keywords\x18\x05 \x03(\t\x12\x18\n\nproject_id\x18\x06 \x01(\tB\x04\xe2\x41\x01\x02\x32\xde\x04\n\x11PublishBuildEvent\x12\xc9\x01\n\x15PublishLifecycleEvent\x12\x36.google.devtools.build.v1.PublishLifecycleEventRequest\x1a\x16.google.protobuf.Empty\"`\x82\xd3\xe4\x93\x02Z\"3/v1/projects/{project_id=*}/lifecycleEvents:publish:\x01*Z \"\x1b/v1/lifecycleEvents:publish:\x01*\x12\xa6\x02\n\x1bPublishBuildToolEventStream\x12<.google.devtools.build.v1.PublishBuildToolEventStreamRequest\x1a=.google.devtools.build.v1.PublishBuildToolEventStreamResponse\"\x85\x01\xda\x41\x34ordered_build_event,notification_keywords,project_id\x82\xd3\xe4\x93\x02H\"*/v1/projects/{project_id=*}/events:publish:\x01*Z\x17\"\x12/v1/events:publish:\x01*(\x01\x30\x01\x1aT\xca\x41 buildeventservice.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformB\x88\x01\n\x1c\x63om.google.devtools.build.v1B\x0c\x42\x61\x63kendProtoP\x01Z=google.golang.org/genproto/googleapis/devtools/build/v1;build\xf8\x01\x01\xca\x02\x15Google\\Cloud\\Build\\V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buildgrid.common.protos.google.devtools.build.v1.publish_build_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.google.devtools.build.v1B\014BackendProtoP\001Z=google.golang.org/genproto/googleapis/devtools/build/v1;build\370\001\001\312\002\025Google\\Cloud\\Build\\V1'
  _PUBLISHLIFECYCLEEVENTREQUEST.fields_by_name['build_event']._options = None
  _PUBLISHLIFECYCLEEVENTREQUEST.fields_by_name['build_event']._serialized_options = b'\342A\001\002'
  _PUBLISHLIFECYCLEEVENTREQUEST.fields_by_name['project_id']._options = None
  _PUBLISHLIFECYCLEEVENTREQUEST.fields_by_name['project_id']._serialized_options = b'\342A\001\002'
  _PUBLISHBUILDTOOLEVENTSTREAMREQUEST.fields_by_name['ordered_build_event']._options = None
  _PUBLISHBUILDTOOLEVENTSTREAMREQUEST.fields_by_name['ordered_build_event']._serialized_options = b'\342A\001\002'
  _PUBLISHBUILDTOOLEVENTSTREAMREQUEST.fields_by_name['project_id']._options = None
  _PUBLISHBUILDTOOLEVENTSTREAMREQUEST.fields_by_name['project_id']._serialized_options = b'\342A\001\002'
  _PUBLISHBUILDEVENT._options = None
  _PUBLISHBUILDEVENT._serialized_options = b'\312A buildeventservice.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform'
  _PUBLISHBUILDEVENT.methods_by_name['PublishLifecycleEvent']._options = None
  _PUBLISHBUILDEVENT.methods_by_name['PublishLifecycleEvent']._serialized_options = b'\202\323\344\223\002Z\"3/v1/projects/{project_id=*}/lifecycleEvents:publish:\001*Z \"\033/v1/lifecycleEvents:publish:\001*'
  _PUBLISHBUILDEVENT.methods_by_name['PublishBuildToolEventStream']._options = None
  _PUBLISHBUILDEVENT.methods_by_name['PublishBuildToolEventStream']._serialized_options = b'\332A4ordered_build_event,notification_keywords,project_id\202\323\344\223\002H\"*/v1/projects/{project_id=*}/events:publish:\001*Z\027\"\022/v1/events:publish:\001*'
  _globals['_PUBLISHLIFECYCLEEVENTREQUEST']._serialized_start=275
  _globals['_PUBLISHLIFECYCLEEVENTREQUEST']._serialized_end=630
  _globals['_PUBLISHLIFECYCLEEVENTREQUEST_SERVICELEVEL']._serialized_start=579
  _globals['_PUBLISHLIFECYCLEEVENTREQUEST_SERVICELEVEL']._serialized_end=630
  _globals['_PUBLISHBUILDTOOLEVENTSTREAMRESPONSE']._serialized_start=632
  _globals['_PUBLISHBUILDTOOLEVENTSTREAMRESPONSE']._serialized_end=749
  _globals['_ORDEREDBUILDEVENT']._serialized_start=752
  _globals['_ORDEREDBUILDEVENT']._serialized_end=904
  _globals['_PUBLISHBUILDTOOLEVENTSTREAMREQUEST']._serialized_start=907
  _globals['_PUBLISHBUILDTOOLEVENTSTREAMREQUEST']._serialized_end=1080
  _globals['_PUBLISHBUILDEVENT']._serialized_start=1083
  _globals['_PUBLISHBUILDEVENT']._serialized_end=1689
# @@protoc_insertion_point(module_scope)
