# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buildgrid/v2/messaging.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buildgrid.common.protos.build.bazel.remote.execution.v2 import remote_execution_pb2 as build_dot_bazel_dot_remote_dot_execution_dot_v2_dot_remote__execution__pb2
from buildgrid.common.protos.google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x62uildgrid/v2/messaging.proto\x12\x0c\x62uildgrid.v2\x1a\x36\x62uild/bazel/remote/execution/v2/remote_execution.proto\x1a#google/longrunning/operations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"N\n\x03Job\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x37\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32\'.build.bazel.remote.execution.v2.Action\"\x87\x02\n\x0f\x43reateOperation\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x16\n\x0eoperation_name\x18\x02 \x01(\t\x12>\n\raction_digest\x18\x03 \x01(\x0b\x32\'.build.bazel.remote.execution.v2.Digest\x12\x11\n\tcacheable\x18\x04 \x01(\x08\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12J\n\x10request_metadata\x18\x06 \x01(\x0b\x32\x30.build.bazel.remote.execution.v2.RequestMetadata\"\x9c\x01\n\x10UpdateOperations\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x36\n\x0foperation_state\x18\x02 \x01(\x0b\x32\x1d.google.longrunning.Operation\x12\x11\n\tcacheable\x18\x03 \x01(\x08\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"l\n\x0cRetryableJob\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x37\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32\'.build.bazel.remote.execution.v2.Action\x12\x13\n\x0brouting_key\x18\x03 \x01(\t\"\x88\x01\n\tBotStatus\x12\x10\n\x08\x62ot_name\x18\x01 \x01(\t\x12/\n\x0b\x61ssignments\x18\x02 \x03(\x0b\x32\x1a.buildgrid.v2.RetryableJob\x12\x38\n\x14\x63onnection_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestampb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buildgrid.common.protos.buildgrid.v2.messaging_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_JOB']._serialized_start=172
  _globals['_JOB']._serialized_end=250
  _globals['_CREATEOPERATION']._serialized_start=253
  _globals['_CREATEOPERATION']._serialized_end=516
  _globals['_UPDATEOPERATIONS']._serialized_start=519
  _globals['_UPDATEOPERATIONS']._serialized_end=675
  _globals['_RETRYABLEJOB']._serialized_start=677
  _globals['_RETRYABLEJOB']._serialized_end=785
  _globals['_BOTSTATUS']._serialized_start=788
  _globals['_BOTSTATUS']._serialized_end=924
# @@protoc_insertion_point(module_scope)
