"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2018 The Bazel Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SemVer(google.protobuf.message.Message):
    """The full version of a given tool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAJOR_FIELD_NUMBER: builtins.int
    MINOR_FIELD_NUMBER: builtins.int
    PATCH_FIELD_NUMBER: builtins.int
    PRERELEASE_FIELD_NUMBER: builtins.int
    major: builtins.int
    """The major version, e.g 10 for 10.2.3."""
    minor: builtins.int
    """The minor version, e.g. 2 for 10.2.3."""
    patch: builtins.int
    """The patch version, e.g 3 for 10.2.3."""
    prerelease: builtins.str
    """The pre-release version. Either this field or major/minor/patch fields
    must be filled. They are mutually exclusive. Pre-release versions are
    assumed to be earlier than any released versions.
    """
    def __init__(
        self,
        *,
        major: builtins.int = ...,
        minor: builtins.int = ...,
        patch: builtins.int = ...,
        prerelease: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["major", b"major", "minor", b"minor", "patch", b"patch", "prerelease", b"prerelease"]) -> None: ...

global___SemVer = SemVer
