"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2018 Google LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.internal.extension_dict
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FieldBehavior:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FieldBehaviorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FieldBehavior.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FIELD_BEHAVIOR_UNSPECIFIED: _FieldBehavior.ValueType  # 0
    """Conventional default for enums. Do not use this."""
    OPTIONAL: _FieldBehavior.ValueType  # 1
    """Specifically denotes a field as optional.
    While all fields in protocol buffers are optional, this may be specified
    for emphasis if appropriate.
    """
    REQUIRED: _FieldBehavior.ValueType  # 2
    """Denotes a field as required.
    This indicates that the field **must** be provided as part of the request,
    and failure to do so will cause an error (usually `INVALID_ARGUMENT`).
    """
    OUTPUT_ONLY: _FieldBehavior.ValueType  # 3
    """Denotes a field as output only.
    This indicates that the field is provided in responses, but including the
    field in a request does nothing (the server *must* ignore it and
    *must not* throw an error as a result of the field's presence).
    """
    INPUT_ONLY: _FieldBehavior.ValueType  # 4
    """Denotes a field as input only.
    This indicates that the field is provided in requests, and the
    corresponding field is not included in output.
    """
    IMMUTABLE: _FieldBehavior.ValueType  # 5
    """Denotes a field as immutable.
    This indicates that the field may be set once in a request to create a
    resource, but may not be changed thereafter.
    """
    UNORDERED_LIST: _FieldBehavior.ValueType  # 6
    """Denotes that a (repeated) field is an unordered list.
    This indicates that the service may provide the elements of the list
    in any arbitrary  order, rather than the order the user originally
    provided. Additionally, the list's order may or may not be stable.
    """
    NON_EMPTY_DEFAULT: _FieldBehavior.ValueType  # 7
    """Denotes that this field returns a non-empty default value if not set.
    This indicates that if the user provides the empty value in a request,
    a non-empty value will be returned. The user will not be aware of what
    non-empty value to expect.
    """

class FieldBehavior(_FieldBehavior, metaclass=_FieldBehaviorEnumTypeWrapper):
    """An indicator of the behavior of a given field (for example, that a field
    is required in requests, or given as output but ignored as input).
    This **does not** change the behavior in protocol buffers itself; it only
    denotes the behavior and may affect how API tooling handles the field.

    Note: This enum **may** receive new values in the future.
    """

FIELD_BEHAVIOR_UNSPECIFIED: FieldBehavior.ValueType  # 0
"""Conventional default for enums. Do not use this."""
OPTIONAL: FieldBehavior.ValueType  # 1
"""Specifically denotes a field as optional.
While all fields in protocol buffers are optional, this may be specified
for emphasis if appropriate.
"""
REQUIRED: FieldBehavior.ValueType  # 2
"""Denotes a field as required.
This indicates that the field **must** be provided as part of the request,
and failure to do so will cause an error (usually `INVALID_ARGUMENT`).
"""
OUTPUT_ONLY: FieldBehavior.ValueType  # 3
"""Denotes a field as output only.
This indicates that the field is provided in responses, but including the
field in a request does nothing (the server *must* ignore it and
*must not* throw an error as a result of the field's presence).
"""
INPUT_ONLY: FieldBehavior.ValueType  # 4
"""Denotes a field as input only.
This indicates that the field is provided in requests, and the
corresponding field is not included in output.
"""
IMMUTABLE: FieldBehavior.ValueType  # 5
"""Denotes a field as immutable.
This indicates that the field may be set once in a request to create a
resource, but may not be changed thereafter.
"""
UNORDERED_LIST: FieldBehavior.ValueType  # 6
"""Denotes that a (repeated) field is an unordered list.
This indicates that the service may provide the elements of the list
in any arbitrary  order, rather than the order the user originally
provided. Additionally, the list's order may or may not be stable.
"""
NON_EMPTY_DEFAULT: FieldBehavior.ValueType  # 7
"""Denotes that this field returns a non-empty default value if not set.
This indicates that if the user provides the empty value in a request,
a non-empty value will be returned. The user will not be aware of what
non-empty value to expect.
"""
global___FieldBehavior = FieldBehavior

FIELD_BEHAVIOR_FIELD_NUMBER: builtins.int
field_behavior: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___FieldBehavior.ValueType]]
"""A designation of a specific field behavior (required, output only, etc.)
in protobuf messages.

Examples:

  string name = 1 [(google.api.field_behavior) = REQUIRED];
  State state = 1 [(google.api.field_behavior) = OUTPUT_ONLY];
  google.protobuf.Duration ttl = 1
    [(google.api.field_behavior) = INPUT_ONLY];
  google.protobuf.Timestamp expire_time = 1
    [(google.api.field_behavior) = OUTPUT_ONLY,
     (google.api.field_behavior) = IMMUTABLE];
"""
