# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/devtools/remoteworkers/v1test2/tasks.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buildgrid.common.protos.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from buildgrid.common.protos.google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1google/devtools/remoteworkers/v1test2/tasks.proto\x12%google.devtools.remoteworkers.v1test2\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\x1a google/protobuf/field_mask.proto\x1a\x17google/rpc/status.proto\"\xb1\x01\n\x04Task\x12\x0c\n\x04name\x18\x01 \x01(\t\x12)\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x43\n\x04logs\x18\x03 \x03(\x0b\x32\x35.google.devtools.remoteworkers.v1test2.Task.LogsEntry\x1a+\n\tLogsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x01\n\nTaskResult\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63omplete\x18\x02 \x01(\x08\x12\"\n\x06status\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\x12$\n\x06output\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\"\n\x04meta\x18\x05 \x01(\x0b\x32\x14.google.protobuf.Any\"\x1e\n\x0eGetTaskRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xab\x01\n\x17UpdateTaskResultRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x41\n\x06result\x18\x02 \x01(\x0b\x32\x31.google.devtools.remoteworkers.v1test2.TaskResult\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0e\n\x06source\x18\x04 \x01(\t\"1\n\x11\x41\x64\x64TaskLogRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06log_id\x18\x02 \x01(\t\"$\n\x12\x41\x64\x64TaskLogResponse\x12\x0e\n\x06handle\x18\x01 \x01(\t2\x88\x04\n\x05Tasks\x12\x91\x01\n\x07GetTask\x12\x35.google.devtools.remoteworkers.v1test2.GetTaskRequest\x1a+.google.devtools.remoteworkers.v1test2.Task\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1test2/{name=**/tasks/*}\x12\xb8\x01\n\x10UpdateTaskResult\x12>.google.devtools.remoteworkers.v1test2.UpdateTaskResultRequest\x1a\x31.google.devtools.remoteworkers.v1test2.TaskResult\"1\x82\xd3\xe4\x93\x02+2!/v1test2/{name=**/tasks/*/result}:\x06result\x12\xaf\x01\n\nAddTaskLog\x12\x38.google.devtools.remoteworkers.v1test2.AddTaskLogRequest\x1a\x39.google.devtools.remoteworkers.v1test2.AddTaskLogResponse\",\x82\xd3\xe4\x93\x02&\"!/v1test2/{name=**/tasks/*}:addLog:\x01*B\xc2\x01\n)com.google.devtools.remoteworkers.v1test2B\x12RemoteWorkersTasksP\x01ZRgoogle.golang.org/genproto/googleapis/devtools/remoteworkers/v1test2;remoteworkers\xa2\x02\x02RW\xaa\x02%Google.DevTools.RemoteWorkers.V1Test2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buildgrid.common.protos.google.devtools.remoteworkers.v1test2.tasks_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.google.devtools.remoteworkers.v1test2B\022RemoteWorkersTasksP\001ZRgoogle.golang.org/genproto/googleapis/devtools/remoteworkers/v1test2;remoteworkers\242\002\002RW\252\002%Google.DevTools.RemoteWorkers.V1Test2'
  _TASK_LOGSENTRY._options = None
  _TASK_LOGSENTRY._serialized_options = b'8\001'
  _TASKS.methods_by_name['GetTask']._options = None
  _TASKS.methods_by_name['GetTask']._serialized_options = b'\202\323\344\223\002\034\022\032/v1test2/{name=**/tasks/*}'
  _TASKS.methods_by_name['UpdateTaskResult']._options = None
  _TASKS.methods_by_name['UpdateTaskResult']._serialized_options = b'\202\323\344\223\002+2!/v1test2/{name=**/tasks/*/result}:\006result'
  _TASKS.methods_by_name['AddTaskLog']._options = None
  _TASKS.methods_by_name['AddTaskLog']._serialized_options = b'\202\323\344\223\002&\"!/v1test2/{name=**/tasks/*}:addLog:\001*'
  _globals['_TASK']._serialized_start=209
  _globals['_TASK']._serialized_end=386
  _globals['_TASK_LOGSENTRY']._serialized_start=343
  _globals['_TASK_LOGSENTRY']._serialized_end=386
  _globals['_TASKRESULT']._serialized_start=389
  _globals['_TASKRESULT']._serialized_end=543
  _globals['_GETTASKREQUEST']._serialized_start=545
  _globals['_GETTASKREQUEST']._serialized_end=575
  _globals['_UPDATETASKRESULTREQUEST']._serialized_start=578
  _globals['_UPDATETASKRESULTREQUEST']._serialized_end=749
  _globals['_ADDTASKLOGREQUEST']._serialized_start=751
  _globals['_ADDTASKLOGREQUEST']._serialized_end=800
  _globals['_ADDTASKLOGRESPONSE']._serialized_start=802
  _globals['_ADDTASKLOGRESPONSE']._serialized_end=838
  _globals['_TASKS']._serialized_start=841
  _globals['_TASKS']._serialized_end=1361
# @@protoc_insertion_point(module_scope)
