# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buildgrid/v2/query_build_events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buildgrid.common.protos.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from buildgrid.common.protos.google.devtools.build.v1 import build_events_pb2 as google_dot_devtools_dot_build_dot_v1_dot_build__events__pb2
from buildgrid.common.protos.google.devtools.build.v1 import publish_build_event_pb2 as google_dot_devtools_dot_build_dot_v1_dot_publish__build__event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%buildgrid/v2/query_build_events.proto\x12\x0c\x62uildgrid.v2\x1a\x1cgoogle/api/annotations.proto\x1a+google/devtools/build/v1/build_events.proto\x1a\x32google/devtools/build/v1/publish_build_event.proto\"4\n\x18QueryEventStreamsRequest\x12\x18\n\x10\x62uild_id_pattern\x18\x01 \x01(\t\"\xef\x01\n\x19QueryEventStreamsResponse\x12I\n\x07streams\x18\x01 \x03(\x0b\x32\x38.buildgrid.v2.QueryEventStreamsResponse.BuildEventStream\x1a\x86\x01\n\x10\x42uildEventStream\x12\x35\n\tstream_id\x18\x01 \x01(\x0b\x32\".google.devtools.build.v1.StreamId\x12;\n\x06\x65vents\x18\x02 \x03(\x0b\x32+.google.devtools.build.v1.OrderedBuildEvent2\x9b\x01\n\x10QueryBuildEvents\x12\x86\x01\n\x11QueryEventStreams\x12&.buildgrid.v2.QueryEventStreamsRequest\x1a\'.buildgrid.v2.QueryEventStreamsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v2/{name=event_streams}b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buildgrid.common.protos.buildgrid.v2.query_build_events_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _QUERYBUILDEVENTS.methods_by_name['QueryEventStreams']._options = None
  _QUERYBUILDEVENTS.methods_by_name['QueryEventStreams']._serialized_options = b'\202\323\344\223\002\032\022\030/v2/{name=event_streams}'
  _globals['_QUERYEVENTSTREAMSREQUEST']._serialized_start=182
  _globals['_QUERYEVENTSTREAMSREQUEST']._serialized_end=234
  _globals['_QUERYEVENTSTREAMSRESPONSE']._serialized_start=237
  _globals['_QUERYEVENTSTREAMSRESPONSE']._serialized_end=476
  _globals['_QUERYEVENTSTREAMSRESPONSE_BUILDEVENTSTREAM']._serialized_start=342
  _globals['_QUERYEVENTSTREAMSRESPONSE_BUILDEVENTSTREAM']._serialized_end=476
  _globals['_QUERYBUILDEVENTS']._serialized_start=479
  _globals['_QUERYBUILDEVENTS']._serialized_end=634
# @@protoc_insertion_point(module_scope)
