# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from buildgrid.common.protos.buildstream.v2 import buildstream_pb2 as buildstream_dot_v2_dot_buildstream__pb2


class ReferenceStorageStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetReference = channel.unary_unary(
                '/buildstream.v2.ReferenceStorage/GetReference',
                request_serializer=buildstream_dot_v2_dot_buildstream__pb2.GetReferenceRequest.SerializeToString,
                response_deserializer=buildstream_dot_v2_dot_buildstream__pb2.GetReferenceResponse.FromString,
                )
        self.UpdateReference = channel.unary_unary(
                '/buildstream.v2.ReferenceStorage/UpdateReference',
                request_serializer=buildstream_dot_v2_dot_buildstream__pb2.UpdateReferenceRequest.SerializeToString,
                response_deserializer=buildstream_dot_v2_dot_buildstream__pb2.UpdateReferenceResponse.FromString,
                )
        self.Status = channel.unary_unary(
                '/buildstream.v2.ReferenceStorage/Status',
                request_serializer=buildstream_dot_v2_dot_buildstream__pb2.StatusRequest.SerializeToString,
                response_deserializer=buildstream_dot_v2_dot_buildstream__pb2.StatusResponse.FromString,
                )


class ReferenceStorageServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetReference(self, request, context):
        """Retrieve a CAS [Directory][build.bazel.remote.execution.v2.Directory]
        digest by name.

        Errors:
        * `NOT_FOUND`: The requested reference is not in the cache.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateReference(self, request, context):
        """Associate a name with a CAS [Directory][build.bazel.remote.execution.v2.Directory]
        digest.

        Errors:
        * `RESOURCE_EXHAUSTED`: There is insufficient storage space to add the
        entry to the cache.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Status(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ReferenceStorageServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetReference': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReference,
                    request_deserializer=buildstream_dot_v2_dot_buildstream__pb2.GetReferenceRequest.FromString,
                    response_serializer=buildstream_dot_v2_dot_buildstream__pb2.GetReferenceResponse.SerializeToString,
            ),
            'UpdateReference': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateReference,
                    request_deserializer=buildstream_dot_v2_dot_buildstream__pb2.UpdateReferenceRequest.FromString,
                    response_serializer=buildstream_dot_v2_dot_buildstream__pb2.UpdateReferenceResponse.SerializeToString,
            ),
            'Status': grpc.unary_unary_rpc_method_handler(
                    servicer.Status,
                    request_deserializer=buildstream_dot_v2_dot_buildstream__pb2.StatusRequest.FromString,
                    response_serializer=buildstream_dot_v2_dot_buildstream__pb2.StatusResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'buildstream.v2.ReferenceStorage', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ReferenceStorage(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetReference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/buildstream.v2.ReferenceStorage/GetReference',
            buildstream_dot_v2_dot_buildstream__pb2.GetReferenceRequest.SerializeToString,
            buildstream_dot_v2_dot_buildstream__pb2.GetReferenceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateReference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/buildstream.v2.ReferenceStorage/UpdateReference',
            buildstream_dot_v2_dot_buildstream__pb2.UpdateReferenceRequest.SerializeToString,
            buildstream_dot_v2_dot_buildstream__pb2.UpdateReferenceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Status(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/buildstream.v2.ReferenceStorage/Status',
            buildstream_dot_v2_dot_buildstream__pb2.StatusRequest.SerializeToString,
            buildstream_dot_v2_dot_buildstream__pb2.StatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
